<?php
/**
 * Testimonials
 *
 * testimonials are the bits across the bottom that provide a name, image, and
 * short quote from satisified customers. Powered by WooTheme's Testimonial Plugin
 *
 * @see http://wordpress.org/extend/plugins/testimonials-by-woothemes/
 *
 * @package Appify
 * @since Appify 1.0
 */

/**
 * Check if the Testimonials plugin is activated.
 *
 * @since Appify 1.0
 *
 * @return boolean If the plugin is active or not.
 */
function appify_has_testimonials() {
	include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
	
	return is_plugin_active( 'testimonials-by-woothemes/woothemes-testimonials.php' );
}

/**
 * Make some small adjustments to the default arguments for the
 * Testimonials shortcode.
 *
 * @since Appify 1.0
 *
 * @param array $args The default arguments for the shortcode
 * @return array $args The adjusted arguments for the shortcode
 */
function appify_testimonials_args( $args ) {
	$args[ 'before' ] = '<section class="testimonials"><h2>' . __( 'What Other People Are Saying About Appify?', 'appify' ) . '</h2>';
	$args[ 'after' ] = '</section>';
	$args[ 'link_title' ] = false;
	$args[ 'size' ] = 125;

	return $args;
}
add_filter( 'woothemes_testimonials_args', 'appify_testimonials_args' );

/**
 * Custom template for the each testimonial output.
 *
 * @since Appify 1.0
 *
 * @param string $tpl The default template (overwritten completely)
 * @param array $args The default arguments for the template
 * @return string $tpl The adjusted HTML template
 */
function appify_testimonials_item_template( $tpl, $args ) {
	$tpl = '<article class="%%CLASS%%">
				<h3>%%TEXT%%</h3>
				<div class="pic">%%AVATAR%%</div> 
			</article>';

	return $tpl;
}
add_filter( 'woothemes_testimonials_item_template', 'appify_testimonials_item_template', 10, 2 );