/**
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 * Things like site title, description, and background color changes.
 */

( function( $ ) {
	var api = wp.customize;

	function appify_nl2br(str) {
		var breakTag = '<br />'

		return (str + '').replace(/([^>\r\n]?)(\r\n|\n\r|\r|\n)/g, '$1' + breakTag + '$2');
	}

	/** Site title and description. */
	wp.customize( 'blogname', function( value ) {
		value.bind( function( to ) {
			$( '.site-title a' ).html( to );
		} );
	} );
	wp.customize( 'blogdescription', function( value ) {
		value.bind( function( to ) {
			$( '.site-description' ).html( to );
		} );
	} );

	/** Hero Title */
	wp.customize( 'appify_hero_title', function( value ) {
		value.bind( function( to ) {
			$( '.hero-title' ).html( to );
		} );
	} );

	/** Hero Description */
	wp.customize( 'appify_hero_description', function( value ) {
		value.bind( function( to ) {
			$( '.hero-description' ).html( appify_nl2br( to ) );
		} );
	} );

	/** Hero App Store Link */
	wp.customize( 'appify_hero_appstore_link', function( value ) {
		value.bind( function( to ) {
			var appstore = $( '.hero_appstore_link' );

			if ( '' != to ) {
				appstore
					.removeClass( 'hidden' )
					.attr( 'href', to );
			} else {
				appstore
					.addClass( 'hidden' );
			}
		} );
	} );

	/** Hero Play Store Link */
	wp.customize( 'appify_hero_playstore_link', function( value ) {
		value.bind( function( to ) {
			var playstore = $( '.hero_playstore_link' );
			
			if ( '' != to ) {
				playstore
					.removeClass( 'hidden' )
					.attr( 'href', to );
			} else {
				playstore
					.addClass( 'hidden' );
			}
		} );
	} );

	/** Hero Image */
	wp.customize( 'appify_hero_image', function( value ) {
		value.bind( function( to ) {
			$( '#iphone .pic img' ).attr( 'src', to );
		} );
	} );

	/** Hero Text Color */
	wp.customize( 'appify_hero_text_color', function( value ) {
		value.bind( function( to ) {
			$( '#iphone .text, #iphone .text h1' ).css( 'color', to );
		} );
	} );

	/** Hero Accent Color */
	wp.customize( 'appify_hero_accent_color', function( value ) {
		value.bind( function( to ) {
			$( '#iphone .text a' ).css( 'color', to );
			$( '#iphone input[type="submit"]' ).css( 'background-color', to );
		} );
	} );

	/** Hero Background Color */
	wp.customize( 'appify_hero_background_color', function( value ) {
		value.bind( function( to ) {
			$( '#masthead' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'appify_hero_background_image', function( value ) {
		value.bind( function( to ) {
			$( '#masthead' ).css( 'background-image', 'url(' + to + ')' );
		} );
	} );

	/* Custom Backgrounds */
	bg = $.map(['image', 'position', 'repeat'], function( prop ) {
		return 'appify_hero_background_' + prop;
	});

	api.when.apply( api, bg ).done( function( image, position_x, repeat ) {
		var body =  $(document.body),
			head =  $( 'head' ),
			style = $( '#cloudify-hero-custom-background-css' ),
			update;

		update = function() {
			var css = '';

			if ( image() ) {
				css += 'background-image: url("' + image() + '");';
				css += 'background-position: top ' + position_x() + ';';
				css += 'background-repeat: ' + repeat() + ';';
			}

			// Refresh the stylesheet by removing and recreating it.
			style.remove();
			style = $('<style type="text/css" id="cloudify-hero-custom-background-css">#masthead { ' + css + ' }</style>').appendTo( head );
		};

		$.each( arguments, function() {
			this.bind( update );
		});
	});

	/** Footer Twitter */
	wp.customize( 'appify_footer_twitter', function( value ) {
		value.bind( function( to ) {
			var twitter = $( '.twitter' );

			if ( '' != to ) {
				twitter.removeClass( 'hidden' );
				twitter.attr( 'href', to );
			}
		} );
	} );

	/** Footer Facebook */
	wp.customize( 'appify_footer_facebook', function( value ) {
		value.bind( function( to ) {
			var facebook = $( '.facebook' );

			if ( '' != to ) {
				facebook.removeClass( 'hidden' );
				facebook.attr( 'href', to );
			}
		} );
	} );

	/** Footer Image */
	wp.customize( 'appify_footer_image', function( value ) {
		value.bind( function( to ) {
			if ( '' != to ) {
				$( 'footer .logo' ).removeClass( 'hidden' );
				$( 'footer .logo img' ).attr( 'src', to );
			} else {
				$( 'footer .logo' ).addClass( 'hidden' );
			}
		} );
	} );
} )( jQuery );